type ProgrammingUnderscore = {
    join: (input: unknown[], separator: string) => string;
    keys: <T>(input: T) => Array<keyof T>;
    toLowerCase: (input: string) => string;
    split: (input: string, separator: string | RegExp, limit?: number) => string[];
    toString: (input: unknown) => string;
    toInt: (input: string) => number;
    toFloat: (input: string) => number;
    replace: (haystack: string, needle: string | RegExp, replace: string) => string;
    slice: <S, T extends string | Array<S>>(items: T, from: number, to?: number) => T;
    reduce: <T, U>(items: T[], callback: (args: {
        item: T;
        index: number;
        total: U;
    }) => ProgrammingLanguage, initial: U) => U;
    indexOf: <T>(items: T[], callback: (args: {
        item: T;
    }) => ProgrammingLanguage) => number;
    some: <T>(items: T[], callback: (args: {
        item: T;
    }) => ProgrammingLanguage) => boolean;
    every: <T>(items: T[], callback: (args: {
        item: T;
    }) => ProgrammingLanguage) => boolean;
    forEach: <T>(items: T[], callback: (args: {
        item: T;
        index: number;
    }) => ProgrammingLanguage) => ProgrammingLanguage;
    map: <T, U>(items: T[], callback: (args: {
        item: T;
        index: number;
        items: T[];
    }) => ProgrammingLanguage) => U[];
    filter: <T>(items: T[], callback: (args: {
        item: T;
    }) => ProgrammingLanguage) => T[];
    includes: <T>(items: T[], item: T) => boolean;
    concat: <T>(...lists: T[][]) => T[];
    assign: <T>(target: Partial<T>, ...overwrite: Array<Partial<T>>) => T;
    find: <T>(items: T[], callback: (args: {
        item: T;
    }) => ProgrammingLanguage, or: T | null) => T;
    sort: <T>(items: T[], callback: (args: {
        a: T;
        b: T;
    }) => ProgrammingLanguage) => T[];
    compare: <T>(a: T, b: T) => number;
    upsert: <T extends {
        id: string | number;
    } | {
        key: string | number;
    }>(list: T[], item: T) => T[];
    shuffle: <T>(list: T[]) => T[];
};
type ProgrammingLanguage = ({
    _name: "fallback";
    value: ProgrammingLanguage;
    fallback: ProgrammingLanguage;
} | {
    _name: "execute";
    code: ProgrammingLanguage;
} | {
    _name: "sub";
    items: ProgrammingLanguage[];
} | {
    _name: "and";
    items: ProgrammingLanguage[];
} | {
    _name: "or";
    items: ProgrammingLanguage[];
} | {
    _name: "add";
    items: ProgrammingLanguage[];
} | {
    _name: "mult";
    items: ProgrammingLanguage[];
} | {
    _name: "div";
    items: ProgrammingLanguage[];
} | {
    _name: "gt";
    a: ProgrammingLanguage;
    b: ProgrammingLanguage;
} | {
    _name: "lt";
    a: ProgrammingLanguage;
    b: ProgrammingLanguage;
} | {
    _name: "gte";
    a: ProgrammingLanguage;
    b: ProgrammingLanguage;
} | {
    _name: "eq";
    a: ProgrammingLanguage;
    b: ProgrammingLanguage;
} | {
    _name: "set";
    variable: ProgrammingLanguage[];
    value: ProgrammingLanguage;
} | {
    _name: "invoke";
    target: ProgrammingLanguage;
    fun: string;
    args: ProgrammingLanguage[];
    sideEffect?: boolean;
} | {
    _name: "get";
    variable: ProgrammingLanguage[];
} | {
    _name: "declare";
    variables: {
        [key: string]: unknown;
    };
    body: ProgrammingLanguage[];
} | {
    _name: "result";
    value: ProgrammingLanguage;
} | {
    _name: "fun";
    name: string;
    args: string[];
    body: ProgrammingLanguage;
} | {
    _name: "condition";
    test: ProgrammingLanguage;
    then: ProgrammingLanguage;
    otherwise?: ProgrammingLanguage;
} | {
    _name: "not";
    item: ProgrammingLanguage;
} | {
    _name: "defined";
    item: ProgrammingLanguage;
}) & {
    dependencies?: string[];
};
type ProgrammingDate = {
    now: () => number;
};
type ProgrammingTimeout = (callback: () => ProgrammingLanguage, ms: number) => ProgrammingLanguage;
type ProgrammingNamedTimeout = (key: string, callback: () => ProgrammingLanguage, ms: number) => ProgrammingLanguage;
type ProgrammingJSON = {
    stringify(input: any, replacer?: unknown, space?: string): string;
    parse(input: string): any;
};
type ProgrammingFetch = (url: string, config: {
    body?: Blob | File | string;
    headers?: Record<string, string>;
    method?: "POST" | "GET" | "PUT" | "DELETE" | "PATCH";
    callback?: (config: {
        response: {
            status: number;
            body: string;
            headers: Record<string, string>;
        };
        error: Error;
    }) => ProgrammingLanguage;
    credentials?: "omit" | "same-origin" | "include";
}) => ProgrammingLanguage;
type ProgrammingConsole = {
    log: (...args: unknown[]) => ProgrammingLanguage;
};
type ProgrammingBaseScope = {
    Math: Math;
    console: ProgrammingConsole;
    Date: ProgrammingDate;
    setTimeout: ProgrammingTimeout;
    debounce: ProgrammingNamedTimeout;
    throttle: ProgrammingNamedTimeout;
    JSON: ProgrammingJSON;
    _: ProgrammingUnderscore;
    fetch: ProgrammingFetch;
    promise: <T>(callback: (config: {
        onResolve: (result: T) => ProgrammingLanguage;
        onReject: (error: Error) => ProgrammingLanguage;
    }) => void) => Promise<T>;
};
export const kotlinBundle: () => string;
export const kotlin: (code: ProgrammingLanguage | undefined, tabs: string) => unknown;
export const swiftBundle: () => string;
export const swift: (code: ProgrammingLanguage | undefined, tabs: string) => unknown;
export const javascriptBundle: (dependencies: Set<string>) => string;
export const javascript: (code: ProgrammingLanguage | undefined, tabs: string) => string;
export const when: (value: string) => (input: Record<string, ProgrammingLanguage>) => ProgrammingLanguage;
export const invoke: ({ fun, args, target, sideEffect, dependencies }: {
    fun: string | symbol;
    args: unknown[];
    target: unknown;
    sideEffect: boolean;
    dependencies: Set<string>;
}) => ProgrammingLanguage;
export const proxy: ({ scope, path, dependencies }: {
    scope: any;
    path: unknown[];
    dependencies: Set<string>;
}) => any;
export const condition: (test: boolean, then: ProgrammingLanguage) => ProgrammingLanguage & {
    otherwise: (otherwise: ProgrammingLanguage) => ProgrammingLanguage;
};
export const code: <T = unknown>(callback: (scope: ProgrammingBaseScope & T) => unknown, dependencies: Set<string>, scope?: T | undefined) => ProgrammingLanguage;
export function symbol<T>(variable: T[], index: number): T;
export function symbol<K extends string | number | symbol, V>(variable: Record<K, V>, index: K): V;
export const add: <T extends string | number>(...items: T[]) => T extends string ? string : number;
export const or: <T>(...items: T[]) => T;
export const and: <T>(...items: T[]) => T;
export const sub: <T>(...items: T[]) => number;
export const not: (item: boolean) => boolean;
export const defined: (item: unknown) => boolean;
export const mult: <T>(...items: T[]) => number;
export const div: <T>(...items: T[]) => number;
export const gte: (a: number, b: number) => boolean;
export const gt: (a: number, b: number) => boolean;
export const lt: (a: number, b: number) => boolean;
export const eq: <T>(a: T, b: T) => boolean;
export const fallback: <T>(value: T | null | undefined, fallback: T) => T;
export const result: (input?: unknown) => ProgrammingLanguage;
export const set: <T>(variable: T, value: T) => ProgrammingLanguage;
export const declare: <T extends Record<string, unknown>>(callback: (input: T) => unknown[], variables: T) => ProgrammingLanguage;
export const block: (input: unknown[]) => ProgrammingLanguage;
export const executeOnly: (code: ProgrammingLanguage) => ProgrammingLanguage;
export const execute: <T>(code: ProgrammingLanguage, scope: T) => unknown;
export const functions: <T, ExtendedScope>(name: string, functions: (scope: ProgrammingBaseScope & ExtendedScope) => T, scope: ExtendedScope) => (() => ProgrammingLanguage) & T;
export const getDependencies: (code: unknown, dependencies?: Set<string>) => Set<string>;

//# sourceMappingURL=index.d.ts.map
